//@ts-check
"use strict";

/**
@typedef Fade
@type {{
  sprite: PIXI.Sprite;
  timer: number;
  directionIn: boolean;
}}
*/

const fadeInDuration = 0.3;
const fadeOutDuration = 1;

/**
 * @returns {Fade}
 */
function createFade() {
  const sprite = new PIXI.Sprite(app.loader.resources["inGame/fade.png"].texture);

  return { sprite, timer: 0, directionIn: false };
}

function startFadeIn() {
  if (inGame.fade.timer === 0) inGame.pixiRoot.addChild(inGame.fade.sprite);
  inGame.fade.timer = fadeInDuration;
  inGame.fade.directionIn = true;
}

function startFadeOut() {
  if (inGame.fade.timer === 0) inGame.pixiRoot.addChild(inGame.fade.sprite);
  inGame.fade.timer = fadeOutDuration;
  inGame.fade.directionIn = false;
}

function clearFade() {
  if (inGame.fade.timer !== 0) {
    inGame.fade.timer = 0;
    inGame.pixiRoot.removeChild(inGame.fade.sprite);
  }
}

/** @param {number} dt - Delta time */
function animateFade(dt) {
  if (inGame.fade.timer === 0) return;

  inGame.fade.timer = Math.max(0, inGame.fade.timer - dt);

  if (inGame.fade.timer === 0) {
    inGame.pixiRoot.removeChild(inGame.fade.sprite);
  } else {
    if (inGame.fade.directionIn) inGame.fade.sprite.alpha = inGame.fade.timer / fadeInDuration;
    else inGame.fade.sprite.alpha = 1 - inGame.fade.timer / fadeOutDuration;
  }
}

function isFading() {
  return inGame.fade.timer !== 0;
}